Opinion Type: | Release Month: | Release Day: |

All Written for July 2014

Case No. | View | Case Style | Note | Disposition | Disposition Date
--- | --- | --- | --- | --- | ---
07-1715 |  | James R. Mitchell vs State of Florida |  | Affirmed | 07/21/2014
11-5126 |  | Alex Diaz De La Portilla vs State of Florida |  | Reversed | 07/14/2014
11-6680 |  | George Jackmore vs In Re: Estate of William Jackmore, etc. et al. |  | Affirmed in Part/Reversed in Part | 07/14/2014
12-2602 |  | Jovita C. Ibeagwa vs State of Florida |  | Affirmed as Modified | 07/01/2014
12-6064 |  | Joseph Daniel Flowers vs State of Florida |  | Affirmed as Modified | 07/22/2014
13-0224 |  | Agency For HealthCare Administration vs Bayfront Medical Center, Inc., et al. |  | Dismissed | 07/16/2014
13-1528 |  | PHILIP MORRIS USA INC. and Liggett Group LLC. vs Nan Kathryn Buchanan, Personal Rep. etc. |  | Affirmed | 07/14/2014
13-1748 |  | Nora Bloxom-Williams vs Florida Public Employees Council 79, et al. |  | Affirmed | 07/16/2014
13-1808 |  | Charles Culp vs State of Florida |  | Affirmed | 07/21/2014
13-2750 |  | Columbia Bank vs Heather Johnson Turbeville et al. | corrected 07/08/14 | Reversed | 07/07/2014
13-2913 |  | Johnny L. Sadler, Jr. vs State of Florida |  | Reversed | 07/14/2014
13-3183 |  | R. J. Reynolds Tobacco Company vs Janice L. Sikes, as Personal etc. |  | Affirmed | 07/09/2014
13-3720 |  | Frank A. L. Mosley vs State of Florida |  | Reversed | 07/08/2014
13-3815 |  | Curtis McClendon vs State of Florida |  | Affirmed in Part/Reversed in Part | 07/08/2014
13-4227 |  | BAC Home Loans Servicing, L.P. vs Donald H. Ellison; et al. |  | Reversed | 07/25/2014
13-4232 |  | Oak Square Joint Venture, a Florida Joint etc. vs U. S. Bank National Association etc. |  | Affirmed in Part/Reversed in Part | 07/07/2014
13-4409 |  | Leon Smith vs City of Daytona Beach Police Dept./City of etc. |  | Affirmed | 07/16/2014
13-4473 |  | Oak Square Joint Venture, a Florida etc. vs U. S. Bank National Association, etc. |  | Affirmed in Part/Reversed in Part | 07/07/2014
13-4903 |  | G. B., Z.L., through his guardian K.L., et al. vs Agency For Persons With Disabilities |  | Reversed | 07/21/2014
13-5053 |  | Joseph R. Biden, I I I, the Attorney General etc. vs John S. Lord, Herbert H. Peyton, et al. |  | Affirmed | 07/16/2014
13-5423 |  | Joennes Gil vs Cargo Force, Inc. and Gallagher Bassett etc. |  | Reversed | 07/01/2014
13-5452 |  | Ft. Myers Real Estate Holdings, LLC vs Department of Business and Professional etc. |  | Affirmed | 07/16/2014
13-5683 |  | William Netting vs State of Florida |  | Reversed | 07/07/2014
13-5988 |  | Noe Guerra vs C.A. Lindman, Inc., and Argonaut Insurance Co. |  | Reversed | 07/21/2014
13-6070 |  | Amanda Pryor, Wife vs David Pryor, Husband |  | Dismissed | 07/22/2014
13-6135 |  | Brad E Parker vs Jodie Ann Parker |  | Reversed | 07/25/2014
14-0363 |  | Antonio R. Hernandez vs State of Florida |  | Affirmed | 07/07/2014
14-0614 |  | Louis Weltman and Phoenix Realty partners, Inc. vs Stephen Riggs and Heritage FFR. LLC., et al |  | Affirmed in Part/Reversed in Part | 07/07/2014
14-0730 |  | Antwan Dilworth vs State of Florida |  | Granted | 07/16/2014
14-0812 |  | Joshua Blankenship vs State of Florida |  | Reversed | 07/25/2014
14-0902 |  | Ronald Thornton vs State of Florida |  | Denied | 07/22/2014
14-0933 |  | Kester Patterson Beryl Patterson vs HSBC Bank USA, National Association etc. |  | Dismissed | 07/02/2014
14-1013 |  | Willie Raymond Petty vs State of Florida |  | Dismissed | 07/01/2014
14-1361 |  | Chanterria Roberts vs State of Florida |  | Affirmed | 07/21/2014
14-1433 |  | Merlin Williams vs State of Florida |  | Denied | 07/01/2014
14-1502 |  | Willie Raymond Petty vs State of Florida |  | Denied | 07/08/2014
14-1758 |  | Victor Bouie vs State of Florida |  | Granted | 07/22/2014
14-1804 |  | Edward J. Mason vs State of Florida |  | Dismissed | 07/03/2014
14-1867 |  | Veronica Vazquez vs CitiMortgage, Inc. |  | Dismissed | 07/22/2014
14-2072 |  | Silvio Hernandez vs State of Florida |  | Dismissed | 07/02/2014
14-2116 |  | Bobbie D. Dressel vs State of Florida |  | Granted | 07/22/2014
14-2132 |  | Marzuq Al-Hakim vs Rick Scott, Governor |  | Dismissed | 07/01/2014
14-2301 |  | Patrick Allen McCall vs State of Florida |  | Dismissed | 07/01/2014
14-2302 |  | Danny O. Davis vs State of Florida |  | Dismissed | 07/03/2014
14-2418 |  | Corey Landon McComas vs State of Florida |  | Dismissed | 07/16/2014
14-2462 |  | Travis McKinney vs Michael D. Crews, Sec. Florida Dept., etc. |  | Dismissed | 07/08/2014
14-2482 |  | City of Jacksonville, et al. vs Germain Lenrod Dubose |  | Dismissed | 07/02/2014
14-2717 |  | Victor W. Duvall vs State of Florida |  | Dismissed | 07/22/2014
14-2804 |  | Dennis Mehaffie vs John Rutherford as Sheriff of Duval etc. |  | Denied | 07/16/2014